import Vuex from 'vuex'
import Vue from 'vue'
import ax from './api'

import submissionNotes from './modules/submission-notes'

Vue.use(Vuex)

const store = new Vuex.Store({
  modules: {
    submissionNotes: submissionNotes
  },
  state: {
    token: '',
    loggedIn: false,
    username: ''
  },
  mutations: {
    'SET_JWT_TOKEN': function (state, token) {
      state.token = token
      ax.defaults.headers.common['Authorization'] = 'JWT ' + state.token
    },
    'LOGIN': function (state, credentials) {
      state.username = credentials.username
      state.loggedIn = true
    },
    'LOGOUT': function (state) {
      state.token = ''
      state.loggedIn = false
    }
  },
  actions: {
    async getToken (context, credentials) {
      const response = await ax.post('api-token-auth/', credentials)
      context.commit('LOGIN', {
        username: credentials.username
      })
      context.commit('SET_JWT_TOKEN', response.data.token)
    }
  }
})

export default store
